Class AssociateDistributionTenantWebAclRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.AssociateDistributionTenantWebAclRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AssociateDistributionTenantWebAclRequest.Builder,AssociateDistributionTenantWebAclRequest>
@Generated("software.amazon.awssdk:codegen")
public final class AssociateDistributionTenantWebAclRequest
extends CloudFrontRequest
implements ToCopyableBuilder<AssociateDistributionTenantWebAclRequest.Builder,AssociateDistributionTenantWebAclRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The ID of the distribution tenant.final StringifMatch()The currentETagof the distribution tenant.static Class<? extends AssociateDistributionTenantWebAclRequest.Builder>final StringtoString()Returns a string representation of this object.final StringThe Amazon Resource Name (ARN) of the WAF web ACL to associate.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The ID of the distribution tenant.
- Returns:
- The ID of the distribution tenant.
-
webACLArn
The Amazon Resource Name (ARN) of the WAF web ACL to associate.
- Returns:
- The Amazon Resource Name (ARN) of the WAF web ACL to associate.
-
ifMatch
The current
ETagof the distribution tenant. This value is returned in the response of theGetDistributionTenantAPI operation.- Returns:
- The current
ETagof the distribution tenant. This value is returned in the response of theGetDistributionTenantAPI operation.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AssociateDistributionTenantWebAclRequest.Builder,AssociateDistributionTenantWebAclRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
public static Class<? extends AssociateDistributionTenantWebAclRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-