Class ConnectionFunctionSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConnectionFunctionSummary.Builder,ConnectionFunctionSummary>
A connection function summary.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe connection function Amazon Resource Name (ARN).final FunctionConfigReturns the value of the ConnectionFunctionConfig property for this object.final InstantThe connection function created time.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The connection function ID.final InstantThe connection function last modified time.final Stringname()The connection function name.static Class<? extends ConnectionFunctionSummary.Builder>final FunctionStagestage()The connection function stage.final StringThe connection function stage.final Stringstatus()The connection function status.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The connection function name.
- Returns:
- The connection function name.
-
id
The connection function ID.
- Returns:
- The connection function ID.
-
connectionFunctionConfig
Returns the value of the ConnectionFunctionConfig property for this object.- Returns:
- The value of the ConnectionFunctionConfig property for this object.
-
connectionFunctionArn
The connection function Amazon Resource Name (ARN).
- Returns:
- The connection function Amazon Resource Name (ARN).
-
status
The connection function status.
- Returns:
- The connection function status.
-
stage
The connection function stage.
If the service returns an enum value that is not available in the current SDK version,
stagewill returnFunctionStage.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstageAsString().- Returns:
- The connection function stage.
- See Also:
-
stageAsString
The connection function stage.
If the service returns an enum value that is not available in the current SDK version,
stagewill returnFunctionStage.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstageAsString().- Returns:
- The connection function stage.
- See Also:
-
createdTime
The connection function created time.
- Returns:
- The connection function created time.
-
lastModifiedTime
The connection function last modified time.
- Returns:
- The connection function last modified time.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConnectionFunctionSummary.Builder,ConnectionFunctionSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-