Class ConnectionGroup
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ConnectionGroup.Builder,ConnectionGroup>
The connection group for your distribution tenants. When you first create a distribution tenant and you don't specify a connection group, CloudFront will automatically create a default connection group for you. When you create a new distribution tenant and don't specify a connection group, the default one will be associated with your distribution tenant.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe ID of the Anycast static IP list.final Stringarn()The Amazon Resource Name (ARN) of the connection group.static ConnectionGroup.Builderbuilder()final InstantThe date and time when the connection group was created.final Booleanenabled()Whether the connection group is enabled.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The ID of the connection group.final BooleanIPv6 is enabled for the connection group.final BooleanWhether the connection group is the default connection group for the distribution tenants.final InstantThe date and time when the connection group was updated.final Stringname()The name of the connection group.final StringThe routing endpoint (also known as the DNS name) that is assigned to the connection group, such as d111111abcdef8.cloudfront.net.static Class<? extends ConnectionGroup.Builder>final Stringstatus()The status of the connection group.final Tagstags()Returns the value of the Tags property for this object.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The ID of the connection group.
- Returns:
- The ID of the connection group.
-
name
The name of the connection group.
- Returns:
- The name of the connection group.
-
arn
The Amazon Resource Name (ARN) of the connection group.
- Returns:
- The Amazon Resource Name (ARN) of the connection group.
-
createdTime
The date and time when the connection group was created.
- Returns:
- The date and time when the connection group was created.
-
lastModifiedTime
The date and time when the connection group was updated.
- Returns:
- The date and time when the connection group was updated.
-
tags
Returns the value of the Tags property for this object.- Returns:
- The value of the Tags property for this object.
-
ipv6Enabled
IPv6 is enabled for the connection group.
- Returns:
- IPv6 is enabled for the connection group.
-
routingEndpoint
The routing endpoint (also known as the DNS name) that is assigned to the connection group, such as d111111abcdef8.cloudfront.net.
- Returns:
- The routing endpoint (also known as the DNS name) that is assigned to the connection group, such as d111111abcdef8.cloudfront.net.
-
anycastIpListId
The ID of the Anycast static IP list.
- Returns:
- The ID of the Anycast static IP list.
-
status
The status of the connection group.
- Returns:
- The status of the connection group.
-
enabled
Whether the connection group is enabled.
- Returns:
- Whether the connection group is enabled.
-
isDefault
Whether the connection group is the default connection group for the distribution tenants.
- Returns:
- Whether the connection group is the default connection group for the distribution tenants.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ConnectionGroup.Builder,ConnectionGroup>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-