Class CopyDistributionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CopyDistributionRequest.Builder,CopyDistributionRequest>

@Generated("software.amazon.awssdk:codegen") public final class CopyDistributionRequest extends CloudFrontRequest implements ToCopyableBuilder<CopyDistributionRequest.Builder,CopyDistributionRequest>
  • Method Details

    • primaryDistributionId

      public final String primaryDistributionId()

      The identifier of the primary distribution whose configuration you are copying. To get a distribution ID, use ListDistributions.

      Returns:
      The identifier of the primary distribution whose configuration you are copying. To get a distribution ID, use ListDistributions.
    • staging

      public final Boolean staging()

      The type of distribution that your primary distribution will be copied to. The only valid value is True, indicating that you are copying to a staging distribution.

      Returns:
      The type of distribution that your primary distribution will be copied to. The only valid value is True, indicating that you are copying to a staging distribution.
    • ifMatch

      public final String ifMatch()

      The version identifier of the primary distribution whose configuration you are copying. This is the ETag value returned in the response to GetDistribution and GetDistributionConfig.

      Returns:
      The version identifier of the primary distribution whose configuration you are copying. This is the ETag value returned in the response to GetDistribution and GetDistributionConfig.
    • callerReference

      public final String callerReference()

      A value that uniquely identifies a request to create a resource. This helps to prevent CloudFront from creating a duplicate resource if you accidentally resubmit an identical request.

      Returns:
      A value that uniquely identifies a request to create a resource. This helps to prevent CloudFront from creating a duplicate resource if you accidentally resubmit an identical request.
    • enabled

      public final Boolean enabled()

      A Boolean flag to specify the state of the staging distribution when it's created. When you set this value to True, the staging distribution is enabled. When you set this value to False, the staging distribution is disabled.

      If you omit this field, the default value is True.

      Returns:
      A Boolean flag to specify the state of the staging distribution when it's created. When you set this value to True, the staging distribution is enabled. When you set this value to False, the staging distribution is disabled.

      If you omit this field, the default value is True.

    • toBuilder

      public CopyDistributionRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<CopyDistributionRequest.Builder,CopyDistributionRequest>
      Specified by:
      toBuilder in class CloudFrontRequest
    • builder

      public static CopyDistributionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CopyDistributionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo