Class CreateKeyValueStoreRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.CreateKeyValueStoreRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateKeyValueStoreRequest.Builder,CreateKeyValueStoreRequest>
@Generated("software.amazon.awssdk:codegen")
public final class CreateKeyValueStoreRequest
extends CloudFrontRequest
implements ToCopyableBuilder<CreateKeyValueStoreRequest.Builder,CreateKeyValueStoreRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringcomment()The comment of the key value store.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ImportSourceThe S3 bucket that provides the source for the import.final Stringname()The name of the key value store.static Class<? extends CreateKeyValueStoreRequest.Builder>final Tagstags()Returns the value of the Tags property for this object.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the key value store. The minimum length is 1 character and the maximum length is 64 characters.
- Returns:
- The name of the key value store. The minimum length is 1 character and the maximum length is 64 characters.
-
comment
The comment of the key value store.
- Returns:
- The comment of the key value store.
-
importSource
The S3 bucket that provides the source for the import. The source must be in a valid JSON format.
- Returns:
- The S3 bucket that provides the source for the import. The source must be in a valid JSON format.
-
tags
Returns the value of the Tags property for this object.- Returns:
- The value of the Tags property for this object.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateKeyValueStoreRequest.Builder,CreateKeyValueStoreRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-