Class CreateStreamingDistributionResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.cloudfront.model.CloudFrontResponse
software.amazon.awssdk.services.cloudfront.model.CreateStreamingDistributionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateStreamingDistributionResponse.Builder,CreateStreamingDistributionResponse>
@Generated("software.amazon.awssdk:codegen")
public final class CreateStreamingDistributionResponse
extends CloudFrontResponse
implements ToCopyableBuilder<CreateStreamingDistributionResponse.Builder,CreateStreamingDistributionResponse>
The returned result of the corresponding request.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringeTag()The current version of the streaming distribution created.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringlocation()The fully qualified URI of the new streaming distribution resource just created.static Class<? extends CreateStreamingDistributionResponse.Builder>final StreamingDistributionThe streaming distribution's information.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.cloudfront.model.CloudFrontResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
streamingDistribution
The streaming distribution's information.
- Returns:
- The streaming distribution's information.
-
location
The fully qualified URI of the new streaming distribution resource just created.
- Returns:
- The fully qualified URI of the new streaming distribution resource just created.
-
eTag
The current version of the streaming distribution created.
- Returns:
- The current version of the streaming distribution created.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateStreamingDistributionResponse.Builder,CreateStreamingDistributionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends CreateStreamingDistributionResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-