Class CustomOriginConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CustomOriginConfig.Builder,CustomOriginConfig>
A custom origin. A custom origin is any origin that is not an Amazon S3 bucket, with one exception. An Amazon S3 bucket that is configured with static website hosting is a custom origin.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CustomOriginConfig.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerhttpPort()The HTTP port that CloudFront uses to connect to the origin.final IntegerThe HTTPS port that CloudFront uses to connect to the origin.final IpAddressTypeSpecifies which IP protocol CloudFront uses when connecting to your origin.final StringSpecifies which IP protocol CloudFront uses when connecting to your origin.final IntegerSpecifies how long, in seconds, CloudFront persists its connection to the origin.final OriginMtlsConfigConfigures mutual TLS authentication between CloudFront and your origin server.final OriginProtocolPolicySpecifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.final StringSpecifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin.final IntegerSpecifies how long, in seconds, CloudFront waits for a response from the origin.final OriginSslProtocolsSpecifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.static Class<? extends CustomOriginConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
httpPort
The HTTP port that CloudFront uses to connect to the origin. Specify the HTTP port that the origin listens on.
- Returns:
- The HTTP port that CloudFront uses to connect to the origin. Specify the HTTP port that the origin listens on.
-
httpsPort
The HTTPS port that CloudFront uses to connect to the origin. Specify the HTTPS port that the origin listens on.
- Returns:
- The HTTPS port that CloudFront uses to connect to the origin. Specify the HTTPS port that the origin listens on.
-
originProtocolPolicy
Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Valid values are:
-
http-only– CloudFront always uses HTTP to connect to the origin. -
match-viewer– CloudFront connects to the origin using the same protocol that the viewer used to connect to CloudFront. -
https-only– CloudFront always uses HTTPS to connect to the origin.
If the service returns an enum value that is not available in the current SDK version,
originProtocolPolicywill returnOriginProtocolPolicy.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginProtocolPolicyAsString().- Returns:
- Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Valid values
are:
-
http-only– CloudFront always uses HTTP to connect to the origin. -
match-viewer– CloudFront connects to the origin using the same protocol that the viewer used to connect to CloudFront. -
https-only– CloudFront always uses HTTPS to connect to the origin.
-
- See Also:
-
-
originProtocolPolicyAsString
Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Valid values are:
-
http-only– CloudFront always uses HTTP to connect to the origin. -
match-viewer– CloudFront connects to the origin using the same protocol that the viewer used to connect to CloudFront. -
https-only– CloudFront always uses HTTPS to connect to the origin.
If the service returns an enum value that is not available in the current SDK version,
originProtocolPolicywill returnOriginProtocolPolicy.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginProtocolPolicyAsString().- Returns:
- Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Valid values
are:
-
http-only– CloudFront always uses HTTP to connect to the origin. -
match-viewer– CloudFront connects to the origin using the same protocol that the viewer used to connect to CloudFront. -
https-only– CloudFront always uses HTTPS to connect to the origin.
-
- See Also:
-
-
originSslProtocols
Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS. Valid values include
SSLv3,TLSv1,TLSv1.1, andTLSv1.2.For more information, see Minimum Origin SSL Protocol in the Amazon CloudFront Developer Guide.
- Returns:
- Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS.
Valid values include
SSLv3,TLSv1,TLSv1.1, andTLSv1.2.For more information, see Minimum Origin SSL Protocol in the Amazon CloudFront Developer Guide.
-
originReadTimeout
Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as the origin response timeout. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don't specify otherwise) is 30 seconds.
For more information, see Response timeout in the Amazon CloudFront Developer Guide.
- Returns:
- Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as
the origin response timeout. The minimum timeout is 1 second, the maximum is 120 seconds, and the
default (if you don't specify otherwise) is 30 seconds.
For more information, see Response timeout in the Amazon CloudFront Developer Guide.
-
originKeepaliveTimeout
Specifies how long, in seconds, CloudFront persists its connection to the origin. The minimum timeout is 1 second, the maximum is 120 seconds, and the default (if you don't specify otherwise) is 5 seconds.
For more information, see Keep-alive timeout (custom origins only) in the Amazon CloudFront Developer Guide.
- Returns:
- Specifies how long, in seconds, CloudFront persists its connection to the origin. The minimum timeout is
1 second, the maximum is 120 seconds, and the default (if you don't specify otherwise) is 5 seconds.
For more information, see Keep-alive timeout (custom origins only) in the Amazon CloudFront Developer Guide.
-
ipAddressType
Specifies which IP protocol CloudFront uses when connecting to your origin. If your origin uses both IPv4 and IPv6 protocols, you can choose
dualstackto help optimize reliability.If the service returns an enum value that is not available in the current SDK version,
ipAddressTypewill returnIpAddressType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromipAddressTypeAsString().- Returns:
- Specifies which IP protocol CloudFront uses when connecting to your origin. If your origin uses both IPv4
and IPv6 protocols, you can choose
dualstackto help optimize reliability. - See Also:
-
ipAddressTypeAsString
Specifies which IP protocol CloudFront uses when connecting to your origin. If your origin uses both IPv4 and IPv6 protocols, you can choose
dualstackto help optimize reliability.If the service returns an enum value that is not available in the current SDK version,
ipAddressTypewill returnIpAddressType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromipAddressTypeAsString().- Returns:
- Specifies which IP protocol CloudFront uses when connecting to your origin. If your origin uses both IPv4
and IPv6 protocols, you can choose
dualstackto help optimize reliability. - See Also:
-
originMtlsConfig
Configures mutual TLS authentication between CloudFront and your origin server.
- Returns:
- Configures mutual TLS authentication between CloudFront and your origin server.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CustomOriginConfig.Builder,CustomOriginConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-