Class DeleteFieldLevelEncryptionConfigRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.DeleteFieldLevelEncryptionConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteFieldLevelEncryptionConfigRequest.Builder,DeleteFieldLevelEncryptionConfigRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteFieldLevelEncryptionConfigRequest
extends CloudFrontRequest
implements ToCopyableBuilder<DeleteFieldLevelEncryptionConfigRequest.Builder,DeleteFieldLevelEncryptionConfigRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The ID of the configuration you want to delete from CloudFront.final StringifMatch()The value of theETagheader that you received when retrieving the configuration identity to delete.static Class<? extends DeleteFieldLevelEncryptionConfigRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The ID of the configuration you want to delete from CloudFront.
- Returns:
- The ID of the configuration you want to delete from CloudFront.
-
ifMatch
The value of the
ETagheader that you received when retrieving the configuration identity to delete. For example:E2QWRUHAPOMQZL.- Returns:
- The value of the
ETagheader that you received when retrieving the configuration identity to delete. For example:E2QWRUHAPOMQZL.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteFieldLevelEncryptionConfigRequest.Builder,DeleteFieldLevelEncryptionConfigRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DeleteFieldLevelEncryptionConfigRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-