Class DeleteKeyGroupRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.DeleteKeyGroupRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteKeyGroupRequest.Builder,DeleteKeyGroupRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteKeyGroupRequest
extends CloudFrontRequest
implements ToCopyableBuilder<DeleteKeyGroupRequest.Builder,DeleteKeyGroupRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The identifier of the key group that you are deleting.final StringifMatch()The version of the key group that you are deleting.static Class<? extends DeleteKeyGroupRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The identifier of the key group that you are deleting. To get the identifier, use
ListKeyGroups.- Returns:
- The identifier of the key group that you are deleting. To get the identifier, use
ListKeyGroups.
-
ifMatch
The version of the key group that you are deleting. The version is the key group's
ETagvalue. To get theETag, useGetKeyGrouporGetKeyGroupConfig.- Returns:
- The version of the key group that you are deleting. The version is the key group's
ETagvalue. To get theETag, useGetKeyGrouporGetKeyGroupConfig.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteKeyGroupRequest.Builder,DeleteKeyGroupRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-