Class DescribeFunctionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.DescribeFunctionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeFunctionRequest.Builder,DescribeFunctionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DescribeFunctionRequest
extends CloudFrontRequest
implements ToCopyableBuilder<DescribeFunctionRequest.Builder,DescribeFunctionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the function that you are getting information about.static Class<? extends DescribeFunctionRequest.Builder>final FunctionStagestage()The function's stage, eitherDEVELOPMENTorLIVE.final StringThe function's stage, eitherDEVELOPMENTorLIVE.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the function that you are getting information about.
- Returns:
- The name of the function that you are getting information about.
-
stage
The function's stage, either
DEVELOPMENTorLIVE.If the service returns an enum value that is not available in the current SDK version,
stagewill returnFunctionStage.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstageAsString().- Returns:
- The function's stage, either
DEVELOPMENTorLIVE. - See Also:
-
stageAsString
The function's stage, either
DEVELOPMENTorLIVE.If the service returns an enum value that is not available in the current SDK version,
stagewill returnFunctionStage.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstageAsString().- Returns:
- The function's stage, either
DEVELOPMENTorLIVE. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeFunctionRequest.Builder,DescribeFunctionRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-