Class FieldLevelEncryption
java.lang.Object
software.amazon.awssdk.services.cloudfront.model.FieldLevelEncryption
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FieldLevelEncryption.Builder,FieldLevelEncryption>
@Generated("software.amazon.awssdk:codegen")
public final class FieldLevelEncryption
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FieldLevelEncryption.Builder,FieldLevelEncryption>
A complex data type that includes the profile configurations and other options specified for field-level encryption.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic FieldLevelEncryption.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) A complex data type that includes the profile configurations specified for field-level encryption.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The configuration ID for a field-level encryption configuration which includes a set of profiles that specify certain selected data fields to be encrypted by specific public keys.final InstantThe last time the field-level encryption configuration was changed.static Class<? extends FieldLevelEncryption.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The configuration ID for a field-level encryption configuration which includes a set of profiles that specify certain selected data fields to be encrypted by specific public keys.
- Returns:
- The configuration ID for a field-level encryption configuration which includes a set of profiles that specify certain selected data fields to be encrypted by specific public keys.
-
lastModifiedTime
The last time the field-level encryption configuration was changed.
- Returns:
- The last time the field-level encryption configuration was changed.
-
fieldLevelEncryptionConfig
A complex data type that includes the profile configurations specified for field-level encryption.
- Returns:
- A complex data type that includes the profile configurations specified for field-level encryption.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FieldLevelEncryption.Builder,FieldLevelEncryption>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-