Class FieldLevelEncryptionList
java.lang.Object
software.amazon.awssdk.services.cloudfront.model.FieldLevelEncryptionList
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FieldLevelEncryptionList.Builder,FieldLevelEncryptionList>
@Generated("software.amazon.awssdk:codegen")
public final class FieldLevelEncryptionList
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FieldLevelEncryptionList.Builder,FieldLevelEncryptionList>
List of field-level encryption configurations.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasItems()For responses, this returns true if the service returned a value for the Items property.final List<FieldLevelEncryptionSummary>items()An array of field-level encryption items.final IntegermaxItems()The maximum number of elements you want in the response body.final StringIf there are more elements to be listed, this element is present and contains the value that you can use for theMarkerrequest parameter to continue listing your configurations where you left off.final Integerquantity()The number of field-level encryption items.static Class<? extends FieldLevelEncryptionList.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
nextMarker
If there are more elements to be listed, this element is present and contains the value that you can use for the
Markerrequest parameter to continue listing your configurations where you left off.- Returns:
- If there are more elements to be listed, this element is present and contains the value that you can use
for the
Markerrequest parameter to continue listing your configurations where you left off.
-
maxItems
The maximum number of elements you want in the response body.
- Returns:
- The maximum number of elements you want in the response body.
-
quantity
The number of field-level encryption items.
- Returns:
- The number of field-level encryption items.
-
hasItems
public final boolean hasItems()For responses, this returns true if the service returned a value for the Items property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
items
An array of field-level encryption items.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasItems()method.- Returns:
- An array of field-level encryption items.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FieldLevelEncryptionList.Builder,FieldLevelEncryptionList>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-