Interface GetConnectionFunctionRequest.Builder
-
- All Superinterfaces:
AwsRequest.Builder,Buildable,CloudFrontRequest.Builder,CopyableBuilder<GetConnectionFunctionRequest.Builder,GetConnectionFunctionRequest>,SdkBuilder<GetConnectionFunctionRequest.Builder,GetConnectionFunctionRequest>,SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetConnectionFunctionRequest
@Mutable @NotThreadSafe public static interface GetConnectionFunctionRequest.Builder extends CloudFrontRequest.Builder, SdkPojo, CopyableBuilder<GetConnectionFunctionRequest.Builder,GetConnectionFunctionRequest>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description GetConnectionFunctionRequest.Builderidentifier(String identifier)The connection function's identifier.GetConnectionFunctionRequest.BuilderoverrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)GetConnectionFunctionRequest.BuilderoverrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)GetConnectionFunctionRequest.Builderstage(String stage)The connection function's stage.GetConnectionFunctionRequest.Builderstage(FunctionStage stage)The connection function's stage.-
Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfiguration
-
Methods inherited from interface software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest.Builder
build
-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
identifier
GetConnectionFunctionRequest.Builder identifier(String identifier)
The connection function's identifier.
- Parameters:
identifier- The connection function's identifier.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
stage
GetConnectionFunctionRequest.Builder stage(String stage)
The connection function's stage.
- Parameters:
stage- The connection function's stage.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
FunctionStage,FunctionStage
-
stage
GetConnectionFunctionRequest.Builder stage(FunctionStage stage)
The connection function's stage.
- Parameters:
stage- The connection function's stage.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
FunctionStage,FunctionStage
-
overrideConfiguration
GetConnectionFunctionRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetConnectionFunctionRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer)
- Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
-