Interface GetFunctionRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CloudFrontRequest.Builder,CopyableBuilder<GetFunctionRequest.Builder,,GetFunctionRequest> SdkBuilder<GetFunctionRequest.Builder,,GetFunctionRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetFunctionRequest
@Mutable
@NotThreadSafe
public static interface GetFunctionRequest.Builder
extends CloudFrontRequest.Builder, SdkPojo, CopyableBuilder<GetFunctionRequest.Builder,GetFunctionRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the function whose code you are getting.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The function's stage, eitherDEVELOPMENTorLIVE.stage(FunctionStage stage) The function's stage, eitherDEVELOPMENTorLIVE.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
name
The name of the function whose code you are getting.
- Parameters:
name- The name of the function whose code you are getting.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
stage
The function's stage, either
DEVELOPMENTorLIVE.- Parameters:
stage- The function's stage, eitherDEVELOPMENTorLIVE.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
stage
The function's stage, either
DEVELOPMENTorLIVE.- Parameters:
stage- The function's stage, eitherDEVELOPMENTorLIVE.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
GetFunctionRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetFunctionRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-