Class KeyValueStoreList
java.lang.Object
software.amazon.awssdk.services.cloudfront.model.KeyValueStoreList
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<KeyValueStoreList.Builder,KeyValueStoreList>
@Generated("software.amazon.awssdk:codegen")
public final class KeyValueStoreList
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<KeyValueStoreList.Builder,KeyValueStoreList>
The key value store list.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic KeyValueStoreList.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasItems()For responses, this returns true if the service returned a value for the Items property.final List<KeyValueStore>items()The items of the key value store list.final IntegermaxItems()The maximum number of items in the key value store list.final StringThe next marker associated with the key value store list.final Integerquantity()The quantity of the key value store list.static Class<? extends KeyValueStoreList.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
nextMarker
The next marker associated with the key value store list.
- Returns:
- The next marker associated with the key value store list.
-
maxItems
The maximum number of items in the key value store list.
- Returns:
- The maximum number of items in the key value store list.
-
quantity
The quantity of the key value store list.
- Returns:
- The quantity of the key value store list.
-
hasItems
public final boolean hasItems()For responses, this returns true if the service returned a value for the Items property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
items
The items of the key value store list.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasItems()method.- Returns:
- The items of the key value store list.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<KeyValueStoreList.Builder,KeyValueStoreList>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-