Class ListDistributionsByConnectionFunctionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.ListDistributionsByConnectionFunctionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListDistributionsByConnectionFunctionRequest.Builder,ListDistributionsByConnectionFunctionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class ListDistributionsByConnectionFunctionRequest
extends CloudFrontRequest
implements ToCopyableBuilder<ListDistributionsByConnectionFunctionRequest.Builder,ListDistributionsByConnectionFunctionRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe distributions by connection function identifier.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmarker()Use this field when paginating results to indicate where to begin in your list.final IntegermaxItems()The maximum number of distributions that you want returned in the response.static Class<? extends ListDistributionsByConnectionFunctionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
marker
Use this field when paginating results to indicate where to begin in your list. The response includes items in the list that occur after the marker. To get the next page of the list, set this field's value to the value of
NextMarkerfrom the current page's response.- Returns:
- Use this field when paginating results to indicate where to begin in your list. The response includes
items in the list that occur after the marker. To get the next page of the list, set this field's value
to the value of
NextMarkerfrom the current page's response.
-
maxItems
The maximum number of distributions that you want returned in the response.
- Returns:
- The maximum number of distributions that you want returned in the response.
-
connectionFunctionIdentifier
The distributions by connection function identifier.
- Returns:
- The distributions by connection function identifier.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListDistributionsByConnectionFunctionRequest.Builder,ListDistributionsByConnectionFunctionRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListDistributionsByConnectionFunctionRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-