Class LoggingConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LoggingConfig.Builder,LoggingConfig>
A complex type that specifies whether access logs are written for the distribution.
If you already enabled standard logging (legacy) and you want to enable standard logging (v2) to send your access logs to Amazon S3, we recommend that you specify a different Amazon S3 bucket or use a separate path in the same bucket (for example, use a log prefix or partitioning). This helps you keep track of which log files are associated with which logging subscription and prevents log files from overwriting each other. For more information, see Standard logging (access logs) in the Amazon CloudFront Developer Guide.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringbucket()The Amazon S3 bucket to store the access logs in, for example,amzn-s3-demo-bucket.s3.amazonaws.com.static LoggingConfig.Builderbuilder()final Booleanenabled()Specifies whether you want CloudFront to save access logs to an Amazon S3 bucket.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanSpecifies whether you want CloudFront to include cookies in access logs, specifytrueforIncludeCookies.final Stringprefix()An optional string that you want CloudFront to prefix to the access logfilenamesfor this distribution, for example,myprefix/.static Class<? extends LoggingConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
enabled
Specifies whether you want CloudFront to save access logs to an Amazon S3 bucket. If you don't want to enable logging when you create a distribution or if you want to disable logging for an existing distribution, specify
falseforEnabled, and specify emptyBucketandPrefixelements. If you specifyfalseforEnabledbut you specify values forBucketandprefix, the values are automatically deleted.- Returns:
- Specifies whether you want CloudFront to save access logs to an Amazon S3 bucket. If you don't want to
enable logging when you create a distribution or if you want to disable logging for an existing
distribution, specify
falseforEnabled, and specify emptyBucketandPrefixelements. If you specifyfalseforEnabledbut you specify values forBucketandprefix, the values are automatically deleted.
-
includeCookies
Specifies whether you want CloudFront to include cookies in access logs, specify
trueforIncludeCookies. If you choose to include cookies in logs, CloudFront logs all cookies regardless of how you configure the cache behaviors for this distribution. If you don't want to include cookies when you create a distribution or if you want to disable include cookies for an existing distribution, specifyfalseforIncludeCookies.- Returns:
- Specifies whether you want CloudFront to include cookies in access logs, specify
trueforIncludeCookies. If you choose to include cookies in logs, CloudFront logs all cookies regardless of how you configure the cache behaviors for this distribution. If you don't want to include cookies when you create a distribution or if you want to disable include cookies for an existing distribution, specifyfalseforIncludeCookies.
-
bucket
The Amazon S3 bucket to store the access logs in, for example,
amzn-s3-demo-bucket.s3.amazonaws.com.- Returns:
- The Amazon S3 bucket to store the access logs in, for example,
amzn-s3-demo-bucket.s3.amazonaws.com.
-
prefix
An optional string that you want CloudFront to prefix to the access log
filenamesfor this distribution, for example,myprefix/. If you want to enable logging, but you don't want to specify a prefix, you still must include an emptyPrefixelement in theLoggingelement.- Returns:
- An optional string that you want CloudFront to prefix to the access log
filenamesfor this distribution, for example,myprefix/. If you want to enable logging, but you don't want to specify a prefix, you still must include an emptyPrefixelement in theLoggingelement.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LoggingConfig.Builder,LoggingConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-