Class OriginMtlsConfig
java.lang.Object
software.amazon.awssdk.services.cloudfront.model.OriginMtlsConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<OriginMtlsConfig.Builder,OriginMtlsConfig>
@Generated("software.amazon.awssdk:codegen")
public final class OriginMtlsConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<OriginMtlsConfig.Builder,OriginMtlsConfig>
Configures mutual TLS authentication between CloudFront and your origin server.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic OriginMtlsConfig.Builderbuilder()final StringThe Amazon Resource Name (ARN) of the client certificate stored in Amazon Web Services Certificate Manager (ACM) that CloudFront uses to authenticate with your origin using Mutual TLS.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends OriginMtlsConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
clientCertificateArn
The Amazon Resource Name (ARN) of the client certificate stored in Amazon Web Services Certificate Manager (ACM) that CloudFront uses to authenticate with your origin using Mutual TLS.
- Returns:
- The Amazon Resource Name (ARN) of the client certificate stored in Amazon Web Services Certificate Manager (ACM) that CloudFront uses to authenticate with your origin using Mutual TLS.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<OriginMtlsConfig.Builder,OriginMtlsConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-