Class TestFunctionResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.cloudfront.model.CloudFrontResponse
software.amazon.awssdk.services.cloudfront.model.TestFunctionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<TestFunctionResponse.Builder,TestFunctionResponse>
@Generated("software.amazon.awssdk:codegen")
public final class TestFunctionResponse
extends CloudFrontResponse
implements ToCopyableBuilder<TestFunctionResponse.Builder,TestFunctionResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic TestFunctionResponse.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends TestFunctionResponse.Builder>final TestResultAn object that represents the result of running the function with the provided event object.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.cloudfront.model.CloudFrontResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
testResult
An object that represents the result of running the function with the provided event object.
- Returns:
- An object that represents the result of running the function with the provided event object.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<TestFunctionResponse.Builder,TestFunctionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-