Class UpdateCachePolicyRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateCachePolicyRequest.Builder,UpdateCachePolicyRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateCachePolicyRequest extends CloudFrontRequest implements ToCopyableBuilder<UpdateCachePolicyRequest.Builder,UpdateCachePolicyRequest>
  • Method Details

    • cachePolicyConfig

      public final CachePolicyConfig cachePolicyConfig()

      A cache policy configuration.

      Returns:
      A cache policy configuration.
    • id

      public final String id()

      The unique identifier for the cache policy that you are updating. The identifier is returned in a cache behavior's CachePolicyId field in the response to GetDistributionConfig.

      Returns:
      The unique identifier for the cache policy that you are updating. The identifier is returned in a cache behavior's CachePolicyId field in the response to GetDistributionConfig.
    • ifMatch

      public final String ifMatch()

      The version of the cache policy that you are updating. The version is returned in the cache policy's ETag field in the response to GetCachePolicyConfig.

      Returns:
      The version of the cache policy that you are updating. The version is returned in the cache policy's ETag field in the response to GetCachePolicyConfig.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateCachePolicyRequest.Builder,UpdateCachePolicyRequest>
      Specified by:
      toBuilder in class CloudFrontRequest
    • builder

      public static UpdateCachePolicyRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends UpdateCachePolicyRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo