Class UpdateConnectionGroupRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.UpdateConnectionGroupRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateConnectionGroupRequest.Builder,UpdateConnectionGroupRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateConnectionGroupRequest
extends CloudFrontRequest
implements ToCopyableBuilder<UpdateConnectionGroupRequest.Builder,UpdateConnectionGroupRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe ID of the Anycast static IP list.builder()final Booleanenabled()Whether the connection group is enabled.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The ID of the connection group.final StringifMatch()The value of theETagheader that you received when retrieving the connection group that you're updating.final BooleanEnable IPv6 for the connection group.static Class<? extends UpdateConnectionGroupRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The ID of the connection group.
- Returns:
- The ID of the connection group.
-
ipv6Enabled
Enable IPv6 for the connection group. For more information, see Enable IPv6 in the Amazon CloudFront Developer Guide.
- Returns:
- Enable IPv6 for the connection group. For more information, see Enable IPv6 in the Amazon CloudFront Developer Guide.
-
ifMatch
The value of the
ETagheader that you received when retrieving the connection group that you're updating.- Returns:
- The value of the
ETagheader that you received when retrieving the connection group that you're updating.
-
anycastIpListId
The ID of the Anycast static IP list.
- Returns:
- The ID of the Anycast static IP list.
-
enabled
Whether the connection group is enabled.
- Returns:
- Whether the connection group is enabled.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateConnectionGroupRequest.Builder,UpdateConnectionGroupRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-