Class VpcOrigin
java.lang.Object
software.amazon.awssdk.services.cloudfront.model.VpcOrigin
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<VpcOrigin.Builder,VpcOrigin>
@Generated("software.amazon.awssdk:codegen")
public final class VpcOrigin
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<VpcOrigin.Builder,VpcOrigin>
An Amazon CloudFront VPC origin.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe account ID of the Amazon Web Services account that owns the VPC origin.final Stringarn()The VPC origin ARN.static VpcOrigin.Builderbuilder()final InstantThe VPC origin created time.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The VPC origin ID.final InstantThe VPC origin last modified time.static Class<? extends VpcOrigin.Builder>final Stringstatus()The VPC origin status.final StringtoString()Returns a string representation of this object.final VpcOriginEndpointConfigThe VPC origin endpoint configuration.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
id
The VPC origin ID.
- Returns:
- The VPC origin ID.
-
arn
The VPC origin ARN.
- Returns:
- The VPC origin ARN.
-
accountId
The account ID of the Amazon Web Services account that owns the VPC origin.
- Returns:
- The account ID of the Amazon Web Services account that owns the VPC origin.
-
status
The VPC origin status.
- Returns:
- The VPC origin status.
-
createdTime
The VPC origin created time.
- Returns:
- The VPC origin created time.
-
lastModifiedTime
The VPC origin last modified time.
- Returns:
- The VPC origin last modified time.
-
vpcOriginEndpointConfig
The VPC origin endpoint configuration.
- Returns:
- The VPC origin endpoint configuration.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<VpcOrigin.Builder,VpcOrigin>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-