Uses of Interface
software.amazon.awssdk.services.cloudfront.model.FieldLevelEncryptionProfileConfig.Builder
Packages that use FieldLevelEncryptionProfileConfig.Builder
-
Uses of FieldLevelEncryptionProfileConfig.Builder in software.amazon.awssdk.services.cloudfront.model
Methods in software.amazon.awssdk.services.cloudfront.model that return FieldLevelEncryptionProfileConfig.BuilderModifier and TypeMethodDescriptionFieldLevelEncryptionProfileConfig.builder()FieldLevelEncryptionProfileConfig.Builder.callerReference(String callerReference) A unique number that ensures that the request can't be replayed.An optional comment for the field-level encryption profile.FieldLevelEncryptionProfileConfig.Builder.encryptionEntities(Consumer<EncryptionEntities.Builder> encryptionEntities) A complex data type of encryption entities for the field-level encryption profile that include the public key ID, provider, and field patterns for specifying which fields to encrypt with this key.FieldLevelEncryptionProfileConfig.Builder.encryptionEntities(EncryptionEntities encryptionEntities) A complex data type of encryption entities for the field-level encryption profile that include the public key ID, provider, and field patterns for specifying which fields to encrypt with this key.Profile name for the field-level encryption profile.FieldLevelEncryptionProfileConfig.toBuilder()Methods in software.amazon.awssdk.services.cloudfront.model that return types with arguments of type FieldLevelEncryptionProfileConfig.BuilderModifier and TypeMethodDescriptionstatic Class<? extends FieldLevelEncryptionProfileConfig.Builder>FieldLevelEncryptionProfileConfig.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.cloudfront.model with type arguments of type FieldLevelEncryptionProfileConfig.BuilderModifier and TypeMethodDescriptionCreateFieldLevelEncryptionProfileRequest.Builder.fieldLevelEncryptionProfileConfig(Consumer<FieldLevelEncryptionProfileConfig.Builder> fieldLevelEncryptionProfileConfig) The request to create a field-level encryption profile.FieldLevelEncryptionProfile.Builder.fieldLevelEncryptionProfileConfig(Consumer<FieldLevelEncryptionProfileConfig.Builder> fieldLevelEncryptionProfileConfig) A complex data type that includes the profile name and the encryption entities for the field-level encryption profile.GetFieldLevelEncryptionProfileConfigResponse.Builder.fieldLevelEncryptionProfileConfig(Consumer<FieldLevelEncryptionProfileConfig.Builder> fieldLevelEncryptionProfileConfig) Return the field-level encryption profile configuration information.UpdateFieldLevelEncryptionProfileRequest.Builder.fieldLevelEncryptionProfileConfig(Consumer<FieldLevelEncryptionProfileConfig.Builder> fieldLevelEncryptionProfileConfig) Request to update a field-level encryption profile.