Class UpdateCachePolicyRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.cloudfront.model.CloudFrontRequest
software.amazon.awssdk.services.cloudfront.model.UpdateCachePolicyRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateCachePolicyRequest.Builder,UpdateCachePolicyRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateCachePolicyRequest
extends CloudFrontRequest
implements ToCopyableBuilder<UpdateCachePolicyRequest.Builder,UpdateCachePolicyRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final CachePolicyConfigA cache policy configuration.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The unique identifier for the cache policy that you are updating.final StringifMatch()The version of the cache policy that you are updating.static Class<? extends UpdateCachePolicyRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
cachePolicyConfig
A cache policy configuration.
- Returns:
- A cache policy configuration.
-
id
The unique identifier for the cache policy that you are updating. The identifier is returned in a cache behavior's
CachePolicyIdfield in the response toGetDistributionConfig.- Returns:
- The unique identifier for the cache policy that you are updating. The identifier is returned in a cache
behavior's
CachePolicyIdfield in the response toGetDistributionConfig.
-
ifMatch
The version of the cache policy that you are updating. The version is returned in the cache policy's
ETagfield in the response toGetCachePolicyConfig.- Returns:
- The version of the cache policy that you are updating. The version is returned in the cache policy's
ETagfield in the response toGetCachePolicyConfig.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateCachePolicyRequest.Builder,UpdateCachePolicyRequest> - Specified by:
toBuilderin classCloudFrontRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-